/*********************************************************************
 *
 * Authors: Paolo Badino   - paolo.badino@cern.ch
 *
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *  GLite Data Agents Common: MySqlDAOConfig Class
 *
 *  Version info: $Id: MySqlDAOConfig.h,v 1.4 2008/11/14 16:04:48 ptedesco Exp $
 *  Release: $Name:  $
 *
 *********************************************************************/
#ifndef GLITE_DATA_AGENTS_DAO_MYSQL_MYSQLDAOCONFIG_H_
#define GLITE_DATA_AGENTS_DAO_MYSQL_MYSQLDAOCONFIG_H_

#include "glite/data/agents/dao/DAOContextFactory.h"
#include "glite/data/agents/dao/mysql/MySqlDAOContext.h"
#include "glite/data/agents/AgentExceptions.h"
#include <glite/data/config/service/Logger.hxx>

namespace glite {
namespace data  {
namespace agents{
namespace dao   {
namespace mysql {

/**
 * DataAccessObject Factory For MySQL
 */
class MySqlDAOConfig : public DAOContextFactory {
public:

    /**
     * Return the singleton instance
     * @return the singleton instance
     */
    static MySqlDAOConfig& instance() /*throw ()*/; 

    /**
     * Initialize a MYSQL DAO Context
     */
    MySqlDAOContext * createContext() /*throw (DAOLogicError, DAOException)*/;
    
    // -------------------------------------------------------------------------
    // Implements DAOContextFactory Method
    // -------------------------------------------------------------------------

    /**
     * Initialize a Oracle DAO Context
     */
    virtual DAOContext * create() /*throw (DAOLogicError, DAOException)*/ {return createContext();}

    /**
     * Check if the the DB Schema is compatible with the requested one
     */
    virtual void checkSchema(DAOContext& ctx, const std::string& table, unsigned int major,unsigned int minor,unsigned int patch) /*throw (DAOLogicError, DAOException)*/;

protected:

    /*
     * Declare Friend Class
     */
    friend class MySqlDAOComponent;

    /**
     * Initialize the Component
     */
    void init() /*throw (DAOLogicError)*/;

    /**
     * Finailize the Component
     */
    void fini();

    /**
     * Set DB User Property
     */
    void user(const std::string& u) {m_user = u;}

    /**
     * DB Password Property
     */
    void password(const std::string& p) {m_password = p;}
    
    /**
     * Database Host Name Property
     */
    void hostName(const std::string& n) {m_hostName = n;}

    /**
     * Database Name Property
     */
    void dbName(const std::string& n) {m_dbName = n;}

    /**
     * Port Property
     */
    void port(unsigned int p) {m_port = p;}
    
    /**
     * Socket Name Property
     */
    void socketName(const std::string& n) {m_socketName = n;}
        
private:

    /**
     * Constructor
     */
    MySqlDAOConfig();

    /**
     * Destructor
     */
    virtual ~MySqlDAOConfig();
    
private:
    
    /**
     * The Logger
     */
    glite::config::Logger m_logger;
    
    /**
     * HostName Property
     */
    std::string m_hostName;

    /**
     * Port Property
     */
    unsigned int m_port;

    /**
     * Name Property
     */
    std::string m_dbName;
    
    /**
     * DB User Property
     */
    std::string m_user;

    /**
     * DB Password Property
     */
    std::string m_password;
    
    /**
     * DB Socket Name Property
     */
    std::string m_socketName;
    
    /**
     * The AgentDN
     */
    std::string m_agentDn;
};

} // End namespace mysql
} // End namespace dao
} // End namespace agents
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_AGENTS_DAO_MYSQL_MYSQLDAOCONFIG_H_
