#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#------------------------------------------------------------------------------
# agents-common.cred.sh
#------------------------------------------------------------------------------

# Install MyProxy UnitTest Data
test_myproxy_install__DEPENDS="init_unit_test"
function test_myproxy_install(){
    # create configuration
    create_config_xml "glite-agents-common-test-myproxy" "${MODULE_TEST_DIR}/etc/glite-agents-common-test-myproxy.config.xml" \
        "${MODULE_CONFIG_TEMPLATES}/agents-sd.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/agents-cred-myproxy.config-template.xml"
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-agents-common-test-myproxy.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-agents-common-test-myproxy.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-agents-common-test-myproxy.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=0 \
        -O agents-cred-myproxy.Repository=/tmp \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/agents-common-test-myproxy.log \
        -O log.Priority=DEBUG
    # Create UnitTest configuration
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-agents-common-test-myproxy.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-agents-common-test-myproxy-sd.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-agents-common-test-myproxy-sd.log-properties \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=0 \
        -O agents-cred-myproxy.Repository=/tmp \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/agents-common-test-myproxy-sd.log \
        -O log.Priority=DEBUG
    # create services.xml
    cat > ${MODULE_TEST_DIR}/etc/services.xml << EOD
<services>
  <service name="CERN-MYPROXY">
    <parameters>
      <endpoint>myproxy://${MYPROXY_SERVER}</endpoint>
      <type>MyProxy</type>
      <version>1.14</version>
    </parameters>
  </service>
  <service name='CERN-FileTransfer'>
    <parameters>
      <endpoint>https://filetransfer.cern.ch:8443/site-fts/glite-data-transfer-fts/services/FileTransfer</endpoint>
      <type>org.glite.FileTransfer</type>
      <version>3.1.0</version>
    </parameters>
    <associatedservices>
      <name>CERN-MYPROXY</name>
    </associatedservices>
  </service>
</services>
EOD
}

test_myproxy__DEPENDS="test_myproxy_install"
function test_myproxy(){
    local TEST_EXE="${MODULE_TEST_DIR}/bin/glite_data_agents_common_test_cred"
    local WORK_DIR="${MODULE_TEST_DIR}/bin"
    (cd ${WORK_DIR} && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        ${TEST_EXE} -u "${MYPROXY_USER_DN}" -p "${MYPROXY_USER_PASSPHRASE}" -m "${MYPROXY_SERVER}" \
        -f "${MYPROXY_CERT}" -l "${MODULE_TEST_DIR}" -c glite-agents-common-test-myproxy -s)
    local res=${?}
    rm -rf /tmp/x509up_dn*
    if [ 0 -ne ${res} ]; then
        return ${res}
    fi
    (cd ${WORK_DIR} && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        ${TEST_EXE} -u "${MYPROXY_USER_DN}" -p "${MYPROXY_USER_PASSPHRASE}" -m "${MYPROXY_SERVER}" \
        -f "${MYPROXY_CERT}" -l "${MODULE_TEST_DIR}" -c glite-agents-common-test-myproxy-sd -s)
    local res=${?}
    rm -rf /tmp/x509up_dn*
    return ${res}
}

test_cred__DEPENDS="test_myproxy"
function test_cred(){
    true
}
