/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Authors:  Zsolt.Molnar <zsolt.molnar@cern.ch>
 *  
 *  Version info: $Id: TestSeStatements.cpp,v 1.1 2010/02/09 14:31:02 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#include "TestSeStatements.h"
#include "SeStatements.h"
#include "DaoHelper.h"
#include "glite/data/agents/dao/oracle/OracleDAOContext.h"
#include "glite/data/agents/dao/DAOContextFactory.h"
#include "glite/data/agents/dao/oracle/ResultSetPtr.h"

#include <boost/scoped_ptr.hpp>

namespace glite   {
namespace data    {
namespace agents  {
namespace dao     {
namespace oracle  {

namespace {
    static const int Fixture_nameColumnIndexInStatement = 1;
    // Order of declaration corresponds to the column index (index range: 1-7)
    // data is from test/dao/oracle/scripts/agents-common-dao-oracle-test-se.sql
    static const std::string Fixture_expected_name = "CERN-Fireman";
    static const std::string Fixture_expected_site = "cern.ch";
    static const std::string Fixture_expected_se_type = "org.glite.FiremanCatalog";
    static const std::string Fixture_expected_version = "cern.ch";
    static const std::string Fixture_expected_endpoint = "cern.ch";
    static const std::string Fixture_expected_state = "";
    static const std::string Fixture_expected_host = "";
}

void TestSeStatements::setUp()
{
    // Create DAO Context
    boost::scoped_ptr<DAOContext> ctx(DAOContextFactory::instance().create());
    CPPUNIT_ASSERT_MESSAGE("Invalid DAO Type", dynamic_cast<OracleDAOContext*>(ctx.get()) != 0);
} 

void TestSeStatements::tearDown()
{
    // EMPTY
} 

// Test strategy: Create the statement simply, then check if the methods of
// Statement behave well.
void TestSeStatements::testCreateGet()
{
    // TODO: Get the context somehow.
    boost::scoped_ptr<OracleDAOContext> ctx(dynamic_cast<OracleDAOContext*>(
        DAOContextFactory::instance().create()));
    SeStatements& statements = SeStatements::instance();
    boost::scoped_ptr< ::oracle::occi::Statement > stm(statements.createGet(*ctx));
    CPPUNIT_ASSERT_EQUAL(std::string(SeStatements::SelectStatement_()), stm->getSQL());

    const std::string nameValue = "testName";
    stm->setString(Fixture_nameColumnIndexInStatement, nameValue);
    CPPUNIT_ASSERT_EQUAL(nameValue, stm->getString(Fixture_nameColumnIndexInStatement));
}

void TestSeStatements::testExecuteQuery()
{
    boost::scoped_ptr<OracleDAOContext> ctx(dynamic_cast<OracleDAOContext*>(
    DAOContextFactory::instance().create()));
    SeStatements& statements = SeStatements::instance();
    boost::scoped_ptr< ::oracle::occi::Statement > stm(statements.createGet(*ctx));
    CPPUNIT_ASSERT_EQUAL(std::string(SeStatements::SelectStatement_()), stm->getSQL());
    stm->setString(Fixture_nameColumnIndexInStatement, Fixture_expected_name);
    ResultSetPtr rs(*stm, stm->executeQuery());
    // Get the data. There must be data available, test it first, then the values.
    CPPUNIT_ASSERT_EQUAL(::oracle::occi::ResultSet::DATA_AVAILABLE, rs->status());
    CPPUNIT_ASSERT_EQUAL(::oracle::occi::ResultSet::DATA_AVAILABLE, rs->next());
    CPPUNIT_ASSERT_EQUAL(static_cast<unsigned int>(1), rs->getNumArrayRows());
    CPPUNIT_ASSERT_EQUAL(rs->getString(1), Fixture_expected_endpoint);
    CPPUNIT_ASSERT_EQUAL(rs->getString(2), Fixture_expected_se_type);
    CPPUNIT_ASSERT_EQUAL(rs->getString(3), Fixture_expected_site);
    CPPUNIT_ASSERT_EQUAL(rs->getString(4), Fixture_expected_name);
    CPPUNIT_ASSERT_EQUAL(rs->getString(5), Fixture_expected_state);
    CPPUNIT_ASSERT_EQUAL(rs->getString(6), Fixture_expected_version);
    CPPUNIT_ASSERT_EQUAL(rs->getString(7), Fixture_expected_host);
}

} // End namespace oracle
} // End namespace dao
} // End namespace agenta
} // End namespace data
} // End namespace glite
