#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Install DAO Oracle UnitTest Data
test_dao_oracle_install__DEPENDS="init_unit_test"
function test_dao_oracle_install(){
    # Create Template for the UnitTest
    create_config_xml "glite-agents-common-test-dao-oracle" "${MODULE_TEST_DIR}/etc/glite-agents-common-test-dao-oracle.config.xml" \
        "${MODULE_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml"
    # Create unit test configuration
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-agents-common-test-dao-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-agents-common-test-dao-oracle.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-agents-common-test-dao-oracle.log-properties \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/agents-common-test-dao-oracle.log \
        -O log.Priority=DEBUG
    # Populate the DB
    local SOURCE_DIR="${MODULE_DIR}/test/dao/oracle/scripts"
    local DEST_DIR="${MODULE_TEST_DIR}/bin"
    cp ${SOURCE_DIR}/*.sql ${DEST_DIR}
    cp ${SOURCE_DIR}/*.sh ${DEST_DIR}
    chmod +x ${DEST_DIR}/agents-common-dao-oracle-test-setup.sh
    (cd ${DEST_DIR} && env TNS_ADMIN=${ORA_TNS_ADMIN} ${DEST_DIR}/agents-common-dao-oracle-test-setup.sh ${ORA_USER} ${ORA_PWD} ${ORA_CONNECTSTRING})
    return ${?}
}

test_dao_oracle__DEPENDS="test_dao_oracle_install"
function test_dao_oracle(){
    local TEST_EXE="${MODULE_TEST_DIR}/bin/glite_data_agents_common_test_dao_oracle"
    local WORK_DIR="${MODULE_TEST_DIR}/bin"
    (cd ${WORK_DIR} && env TNS_ADMIN=${ORA_TNS_ADMIN} ${TEST_EXE} -l ${MODULE_TEST_DIR} -s)
    return ${?}
}

