#!/usr/bin/python
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import glite.data.agents
import glite.data.agents.sd
import glite.data.agents.utils
import time
    
def test_logger():
    glite.data.agents.utils.Log("test-python",glite.data.agents.utils.LogPriority.Info ,"test_logger called")
    glite.data.agents.utils.LogDebug("test-python","test_logger DEBUG")
    glite.data.agents.utils.LogInfo ("test-python","test_logger INFO")
    glite.data.agents.utils.LogWarn ("test-python","test_logger WARN")
    glite.data.agents.utils.LogError("test-python","test_logger ERROR")

def test_url():
    glite.data.agents.utils.Log("test-python",glite.data.agents.utils.LogPriority.Info ,"test_url called")
    url_str = "srm://testhost.cern.ch:8443/srm/managerv1?SFN=/dpm/cern.ch/test_file"
    url = glite.data.agents.utils.Url(url_str)
    if url.isGood() :
        glite.data.agents.utils.LogInfo("test-python","Got <%s>://<%s>:<%d>/<%s>?<%s>" % (url.schema,url.host,url.port,url.path,url.query))
    else:
        glite.data.agents.utils.LogError("test-python","Failed to process Url")
    url_str2 = url.str()
    if url_str == url_str2 :
        glite.data.agents.utils.LogInfo("test-python","Same URL")
    else :
        glite.data.agents.utils.LogInfo("test-python","<%s> differs from <%s>" % (url_str,url_str2))

def test_guid():
    glite.data.agents.utils.Log("test-python",glite.data.agents.utils.LogPriority.Info ,"test_guid called")
    # Create Guid
    guid = glite.data.agents.utils.Guid()
    if(guid.isNull() == False):
        glite.data.agents.utils.LogInfo("test-python","Got %s" % (guid))
        glite.data.agents.utils.LogInfo("test-python","Hash: %d:%d" % (guid.crossSumHash(),guid.hash()))
    else:
        glite.data.agents.utils.LogError("test-python","Failed to create Guid")
    # Create From String
    guid_str = "92a83305-0984-40d6-87c6-0ae4b6acd974"
    guid = glite.data.agents.utils.Guid(guid_str)
    if(guid.isNull() == False):
        glite.data.agents.utils.LogInfo("test-python","Got %s" % (guid))
    else:
        glite.data.agents.utils.LogError("test-python","Failed to create Guid")
        glite.data.agents.utils.LogInfo("test-python","Hash: %d:%d" % (guid.crossSumHash(),guid.hash()))
    guid_str2 = str(guid)
    if guid_str == guid_str2 :
        glite.data.agents.utils.LogInfo("test-python","Same Guid")
    else :
        glite.data.agents.utils.LogInfo("test-python","<%s> differs from <%s>" % (guid_str,guid_str2))
    # Create Empty Guid
    null_guid = glite.data.agents.utils.Guid("")
    if(null_guid.isNull() == True):
        glite.data.agents.utils.LogInfo("test-python","Got Null Guid : %s" % (null_guid))
        glite.data.agents.utils.LogInfo("test-python","Hash: %d:%d" % (null_guid.crossSumHash(),null_guid.hash()))
    else:
        glite.data.agents.utils.LogError("test-python","Failed to create null Guid")
    # Compare Guids
    if null_guid < guid: 
        glite.data.agents.utils.LogInfo("test-python","Null less than full")
    else:
        glite.data.agents.utils.LogInfo("test-python","Null greater than full")

 
def test_utils():
    glite.data.agents.utils.Log("test-python",glite.data.agents.utils.LogPriority.Info ,"test_utils called")
    # Test logger
    test_logger()
    # Test Url
    test_url()
    # Test Guid
    test_guid()
    
def test_sd():
    glite.data.agents.utils.Log("test-python",glite.data.agents.utils.LogPriority.Info ,"test_sd called")
    svc1 = glite.data.agents.sd.GetService("testhost.cern.ch","SRM")
    if svc1 :
        glite.data.agents.utils.LogInfo("test-python","Got Service %s Type %s" % (svc1.name,svc1.type))
    else :
        glite.data.agents.utils.LogError("test-python","No Service on host testhost.cern.ch")
    svc2 = glite.data.agents.sd.GetServiceByType("SRM")
    if svc2 :
        glite.data.agents.utils.LogInfo("test-python","Got Service %s Type %s" % (svc2.name,svc2.type))
    else :
        glite.data.agents.utils.LogError("test-python","No Service of type SRM")
    svc3 = glite.data.agents.sd.GetAssociatedService("testhost.cern.ch","SRM","gsiftp")
    if svc3 :
        glite.data.agents.utils.LogInfo("test-python","Got Service %s Type %s" % (svc3.name,svc3.type))
    else :
        glite.data.agents.utils.LogError("test-python","No Associated Service of GridFTP found") 
    if svc1 :        
        prop = glite.data.agents.sd.GetServiceProperty(svc1,"SEMountPoint")
        glite.data.agents.utils.LogInfo("test-python","Got Property value %s" % (prop))
    site = glite.data.agents.sd.GetSiteName("testhost.cern.ch","SRM")
    glite.data.agents.utils.LogInfo("test-python","Got Site %s" % (site))

def foo(s):
    glite.data.agents.utils.Log("test-python",glite.data.agents.utils.LogPriority.Info ,"unittest called with " + s)
    # Test Utils
    test_utils()
    # Test SD
    test_sd()
    glite.data.agents.utils.Log("test-python",glite.data.agents.utils.LogPriority.Debug,"Returning " + str(len(s)))
    return len(s)

def test_get_proxy(dn,cred,endpoint):
    glite.data.agents.utils.Log("test-python",glite.data.agents.utils.LogPriority.Info ,"test_get_proxy for dn " + dn)
    proxy_file = glite.data.agents.utils.GetProxyFileName(dn,cred,endpoint);
    glite.data.agents.utils.Log("test-python",glite.data.agents.utils.LogPriority.Info ,"test_get_proxy returns %s" % (proxy_file))
    return proxy_file
    
def test():
    foo("Hello World");
    
# Main function    
if __name__ == "__main__":
    test()
